@@ -149,18 +149,10 @@ class SessionAuth(AuthBase):
         :raises: AccessError
         :raises: HTTPError
         """
-        target_uri = None
-        try:
-            target_uri = self._root_resource.get_sessions_path()
-        except exceptions.MissingAttributeError:
-            LOG.debug('Missing Sessions attribute under Links in Root '
-                      'Service, we\'ll try to determine it from Session '
-                      'Service')
         session_service = self._root_resource.get_session_service()
         session_auth_token, session_uri = (
             session_service.create_session(self._username,
-                                           self._password,
-                                           target_uri=target_uri))
+                                           self._password))
         self._session_key = session_auth_token
         self._session_resource_id = session_uri
         self._connector.set_http_session_auth(session_auth_token)
@@ -207,6 +199,16 @@ class SessionAuth(AuthBase):
         """Reset active session related attributes."""
         self._session_key = None
         self._session_resource_id = None
+        # Requests session object data is merged with user submitted data
+        # per https://requests.readthedocs.io/en/master/user/advanced/
+        # so we need to clear data explicitly set on the session too.
+        self._connector._session.auth = None
+        if 'X-Auth-Token' in self._connector._session.headers:
+            # Delete the token value that was saved to the session
+            # as otherwise we would end up with a dictionary containing
+            # a {'X-Auth-Token': null} being sent across to the remote
+            # bmc.
+            del self._connector._session.headers['X-Auth-Token']
 
 
 class SessionOrBasicAuth(SessionAuth):
