@@ -91,31 +91,24 @@ class SessionService(base.ResourceBase):
         """
         self._conn.delete(session_uri)
 
-    def create_session(self, username, password, target_uri=None):
+    def create_session(self, username, password):
         """This function will try to create a session.
 
-        :param username: the username of the user requesting a new session
-        :param password: the password associated to the user requesting
-            a new session
-        :param target_uri: the "Sessions" uri, usually in the form:
-            '/redfish/v1/SessionService/Sessions'
         :returns: A session key and uri in the form of a tuple
         :raises: MissingXAuthToken
         :raises: ConnectionError
         :raises: AccessError
         :raises: HTTPError
         """
-        if not target_uri:
-            try:
-                target_uri = self._get_sessions_collection_path()
-            except Exception:
-                # Defaulting to /Sessions
-                target_uri = self.path + '/Sessions'
+        try:
+            target_uri = self._get_sessions_collection_path()
+        except Exception:
+            # Defaulting to /Sessions
+            target_uri = self.path + '/Sessions'
 
         data = {'UserName': username, 'Password': password}
-        headers = {'X-Auth-Token': None}
-
-        rsp = self._conn.post(target_uri, data=data, headers=headers)
+        LOG.debug("Requesting new session from %s.", target_uri)
+        rsp = self._conn.post(target_uri, data=data)
         session_key = rsp.headers.get('X-Auth-Token')
         if session_key is None:
             raise exceptions.MissingXAuthToken(
