@@ -14,8 +14,8 @@
 
 
 import json
+from unittest import mock
 
-import mock
 
 from sushy.resources import constants as res_cons
 from sushy.resources.registry import message_registry
